@@ -10,7 +10,7 @@
 #include <ctype.h>
 #include "netacct.h"
 
-char *rcs_revision_config_c = "$Revision: 1.4 $";
+char *rcs_revision_config_c = "$Revision: 1.9 $";
 
 /* 
  * This routine reads all the configuration from the file fname.
@@ -28,12 +28,17 @@ struct config *read_config(char *fname)
 
     cfg -> filename = NULL;
     cfg -> dumpname = NULL;
+    cfg -> debugname = NULL;
     cfg -> flush = DEFAULT_FLUSH;
     cfg -> ignoremask = inet_addr(DEFAULT_IGNOREMASK);
     cfg -> err_delay = DEFAULT_ERR_DELAY;
     cfg -> ignorenet = NULL;
+    cfg -> dontignore = NULL;
     cfg -> promisc = NULL;
     cfg -> fdelay = DEFAULT_FDELAY;
+    cfg -> disabled = 0;
+    cfg -> dynamicip = NULL;
+    cfg -> excludenamelookup = NULL;
     debug_level = 0;
     dev2line = NULL;
 
@@ -97,6 +102,17 @@ struct config *read_config(char *fname)
 			    cfg->dumpname = strdup(value);
 			    syslog(LOG_DEBUG,"config: set dumpfile to %s\n",cfg->dumpname);
 			}
+		    else if(strcasecmp(kwd, "debugfile")==0)
+			{
+			    cfg->debugname = strdup(value);
+			    syslog(LOG_DEBUG,"config: set debugfile to %s\n",cfg->debugname);
+			}
+		    else if(strcasecmp(kwd, "dynamicip")==0)
+			{
+			  if(value[strlen(value)-1]=='/') value[strlen(value)-1]='\0';
+			  cfg->dynamicip = strdup(value);
+			  syslog(LOG_DEBUG,"config: set dynamicip to %s\n",cfg->dynamicip);
+			}
 		    else if(strcasecmp(kwd, "ignoremask")==0)
 			{
 			    cfg->ignoremask = inet_addr(value);
@@ -107,6 +123,21 @@ struct config *read_config(char *fname)
 			    debug_level = atoi(value);
 			    syslog(LOG_DEBUG,"config: set debugging level to %d\n",debug_level);
 			}
+		    else if(strcasecmp(kwd, "disable")==0)
+			{
+			  int field;
+			  field = atoi(value);
+			  if((field < MIN_DISABLE) || (field > MAX_DISABLE))
+			    {
+			      syslog(LOG_ERR, "config file: invalid disable statement\n");
+			      return NULL;
+			    }
+			  else
+			    {
+			      cfg->disabled |= BITMASK(field);
+			      syslog(LOG_DEBUG,"config: disabled field %d\n",field);
+			    }
+			}
 		    else if(strcasecmp(kwd, "ignorenet")==0)
 			{
 			    struct ipnetwork *tmp;
@@ -132,6 +163,73 @@ struct config *read_config(char *fname)
 					   intoa(cfg -> ignorenet -> netmask));
 				}
 			}
+		    else if(strcasecmp(kwd, "exclude-name-lookup")==0)
+			{
+			    struct ipnetwork *tmp;
+			    char *mask;
+
+			    mask  = value + strcspn(value," \t");
+			    *mask++ = '\0';
+			    while(isspace(*mask)) mask++;
+
+			    tmp = malloc(sizeof(struct ipnetwork));
+			    
+			    if(tmp != NULL)
+				{
+				    tmp -> netnumber = inet_addr(value);
+				    tmp -> netmask = inet_addr(mask);
+				    tmp -> next = cfg -> excludenamelookup;
+				    cfg -> excludenamelookup = tmp;
+				    syslog(LOG_DEBUG,
+					   "config: added exclude-name-lookup network (netnumber %s)\n",
+					   intoa(cfg -> excludenamelookup -> netnumber));
+				    syslog(LOG_DEBUG,
+					   "config: added exclude-name-lookup network (netmask %s)\n",
+					   intoa(cfg -> excludenamelookup -> netmask));
+				}
+			}
+		    else if(strcasecmp(kwd, "dynamicnet")==0)
+			{
+			    char *mask;
+
+			    mask  = value + strcspn(value," \t");
+			    *mask++ = '\0';
+			    while(isspace(*mask)) mask++;
+
+			    cfg -> dynamicnet.netnumber = inet_addr(value);
+			    cfg -> dynamicnet.netmask = inet_addr(mask);
+			    syslog(LOG_DEBUG,
+				   "config: set dynamic network (netnumber %s)\n",
+				   intoa(cfg -> dynamicnet.netnumber));
+			    syslog(LOG_DEBUG,
+				   "config: set dynamic network (netmask %s)\n",
+				   intoa(cfg -> dynamicnet.netmask));
+			}
+		    else if(strcasecmp(kwd, "dontignore")==0)
+			{
+			    struct ipnetwork *tmp;
+			    char *mask;
+
+			    mask  = value + strcspn(value," \t");
+			    *mask++ = '\0';
+			    while(isspace(*mask)) mask++;
+
+			    tmp = malloc(sizeof(struct ipnetwork));
+			    
+			    if(tmp != NULL)
+				{
+				    tmp -> netnumber = inet_addr(value);
+				    tmp -> netmask = inet_addr(mask);
+				    tmp -> next = cfg -> dontignore;
+				    cfg -> dontignore = tmp;
+				    syslog(LOG_DEBUG,
+					   "config: added dontignore network (netnumber %s)\n",
+					   intoa(cfg -> dontignore -> netnumber));
+				    syslog(LOG_DEBUG,
+					   "config: added dontignore network (netmask %s)\n",
+					   intoa(cfg -> dontignore -> netmask));
+				}
+			}
 		    else if(strcasecmp(kwd, "device")==0)
 			{
 			    struct promisc_device *tmp;
@@ -190,7 +288,14 @@ struct config *read_config(char *fname)
 	    syslog(LOG_ERR, "config file: no dumpfile given\n");
 	    return NULL;
 	}
+
+    if(cfg->debugname == NULL)
+      {
+	syslog(LOG_INFO, "config file: no debugfile given, using /dev/null\n");
+	cfg->debugname = strdup("/dev/null");
+      }
     
     fclose(f);
     return cfg;
 }
+          
